Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct {
conf.Configuration
}
Server Data Structure for holding the configuration and logger
func NewServer ¶
func NewServer(c conf.Configuration) *Server
NewServer function creates a new server and return a pointer to it
func (*Server) RootHandler ¶
func (s *Server) RootHandler(w http.ResponseWriter, r *http.Request)
RootHandler is the controller responsible for the frontend
func (*Server) SearchFile ¶
func (s *Server) SearchFile(w http.ResponseWriter, r *http.Request)
SearchFile is the controller that helps with indexing the file
Click to show internal directories.
Click to hide internal directories.